export interface Reference {
    $ref: string;
}
export declare function isReference(schema: any): schema is Reference;
export interface JsonSchema {
    deprecated?: boolean;
    description?: string;
    readOnly?: boolean;
    title?: string;
    writeOnly?: boolean;
}
export interface NullJsonSchema extends JsonSchema {
    allOf?: Array<NullJsonSchema>;
    anyOf?: Array<NullJsonSchema>;
    const?: null;
    default?: null;
    enum?: Array<null>;
    examples?: Array<null>;
    not?: NullJsonSchema;
    oneOf?: Array<NullJsonSchema>;
    type?: 'null' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isNullJsonSchema(schema: any): schema is NullJsonSchema;
export interface BooleanJsonSchema extends JsonSchema {
    allOf?: Array<BooleanJsonSchema>;
    anyOf?: Array<BooleanJsonSchema>;
    const?: boolean;
    default?: boolean;
    enum?: Array<boolean>;
    examples?: Array<boolean>;
    not?: BooleanJsonSchema;
    oneOf?: Array<BooleanJsonSchema>;
    type?: 'boolean' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isBooleanJsonSchema(schema: any): schema is BooleanJsonSchema;
export interface StringJsonSchema extends JsonSchema {
    allOf?: Array<StringJsonSchema>;
    anyOf?: Array<StringJsonSchema>;
    const?: string;
    default?: string;
    enum?: Array<string>;
    examples?: Array<string>;
    maxLength?: number;
    minLength?: number;
    not?: StringJsonSchema;
    oneOf?: Array<StringJsonSchema>;
    pattern?: string;
    type?: 'string' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isStringJsonSchema(schema: any): schema is StringJsonSchema;
export interface NumberJsonSchema extends JsonSchema {
    allOf?: Array<NumberJsonSchema>;
    anyOf?: Array<NumberJsonSchema>;
    const?: number;
    default?: number;
    enum?: Array<number>;
    examples?: Array<number>;
    exclusiveMaximum?: number;
    exclusiveMinimum?: number;
    maximum?: number;
    minimum?: number;
    multipleOf?: number;
    not?: NumberJsonSchema;
    oneOf?: Array<NumberJsonSchema>;
    type?: 'number' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isNumberJsonSchema(schema: any): schema is NumberJsonSchema;
export interface IntegerJsonSchema extends JsonSchema {
    allOf?: Array<IntegerJsonSchema>;
    anyOf?: Array<IntegerJsonSchema>;
    const?: number;
    default?: number;
    enum?: Array<number>;
    examples?: Array<number>;
    exclusiveMaximum?: number;
    exclusiveMinimum?: number;
    maximum?: number;
    minimum?: number;
    multipleOf?: number;
    not?: IntegerJsonSchema;
    oneOf?: Array<IntegerJsonSchema>;
    type?: 'integer' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
}
export declare function isIntegerJsonSchema(schema: any): schema is IntegerJsonSchema;
export interface ArrayJsonSchema extends JsonSchema {
    allOf?: Array<ArrayJsonSchema>;
    anyOf?: Array<ArrayJsonSchema>;
    const?: Array<any>;
    contains?: JsonSchema;
    default?: Array<any>;
    enum?: Array<Array<any>>;
    examples?: Array<Array<any>>;
    items?: JsonSchema;
    maxContains?: number;
    maxItems?: number;
    minContains?: number;
    minItems?: number;
    not?: ArrayJsonSchema;
    oneOf?: Array<ArrayJsonSchema>;
    prefixItems?: Array<JsonSchema>;
    type?: 'array' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
    uniqueItems?: boolean;
}
export declare function isArrayJsonSchema(schema: any): schema is ArrayJsonSchema;
export interface ObjectJsonSchema extends JsonSchema {
    additionalProperties?: JsonSchema;
    allOf?: Array<ObjectJsonSchema>;
    anyOf?: Array<ObjectJsonSchema>;
    const?: Record<string, any>;
    default?: Record<string, any>;
    dependentRequired?: Record<string, Array<string>>;
    enum?: Array<Record<string, any>>;
    examples?: Array<Record<string, any>>;
    maxProperties?: number;
    minProperties?: number;
    not?: ObjectJsonSchema;
    oneOf?: Array<ObjectJsonSchema>;
    patternProperties?: {
        [propertyNameRegex: string]: JsonSchema;
    };
    properties?: {
        [propertyName: string]: JsonSchema;
    };
    propertyNames?: JsonSchema;
    required?: Array<string>;
    type?: 'object' | Array<'null' | 'boolean' | 'string' | 'integer' | 'number' | 'array' | 'object'>;
    writeOnly?: boolean;
}
export declare function isObjectJsonSchema(schema: any): schema is ObjectJsonSchema;
export interface AnyJsonSchema extends JsonSchema {
    additionalProperties?: never;
    allOf?: Array<JsonSchema>;
    anyOf?: Array<JsonSchema>;
    const?: any;
    contains?: never;
    default?: any;
    dependentRequired?: never;
    enum?: Array<any>;
    examples?: Array<any>;
    exclusiveMaximum?: never;
    exclusiveMinimum?: never;
    items?: never;
    maxContains?: never;
    maxItems?: never;
    maxLength?: never;
    maxProperties?: never;
    maximum?: never;
    minContains?: never;
    minItems?: never;
    minLength?: never;
    minProperties?: never;
    minimum?: never;
    multipleOf?: never;
    not?: JsonSchema;
    oneOf?: Array<JsonSchema>;
    pattern?: never;
    patternProperties?: never;
    prefixItems?: never;
    properties?: never;
    propertyNames?: never;
    required?: never;
    type?: never;
    uniqueItems?: never;
    writeOnly?: boolean;
}
export declare function isAnyJsonSchema(schema: any): schema is AnyJsonSchema;
//# sourceMappingURL=jsonSchema.d.ts.map